//>>built
define("dojo/nls/pmbdojo_nb",{"dijit/form/nls/validate":{invalidMessage:"Den angitte verdien er ikke gyldig.",missingMessage:"Denne verdien er obligatorisk.",rangeMessage:"Denne verdien er utenfor gyldig omr\u00e5de.",_localized:{}},"dojo/cldr/nls/number":{scientificFormat:"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]",infinity:"\u221e",superscriptingExponent:"\u00d7",list:";",percentSign:"%",minusSign:"\u2212","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000\u00a0bill",
"currencySpacing-afterCurrency-insertBetween":"\u00a0",nan:"NaN",plusSign:"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]",currencyFormat:"\u00a4\u00a0#,##0.00",perMille:"\u2030",group:"\u00a0",percentFormat:"#,##0\u00a0%","decimalFormat-long":"000 billioner",decimalFormat:"#,##0.###",decimal:",","currencySpacing-beforeCurrency-insertBetween":"\u00a0",exponential:"E",_localized:{}},"dijit/form/nls/ComboBox":{previousMessage:"Tidligere valg",
nextMessage:"Flere valg",_localized:{}},"dijit/nls/loading":{loadingState:"Laster inn...",errorState:"Det oppsto en feil",_localized:{}},"dijit/nls/common":{buttonOk:"OK",buttonCancel:"Avbryt",buttonSave:"Lagre",itemClose:"Lukk",_localized:{}},"dijit/_editor/nls/commands":{bold:"Fet",copy:"Kopier",cut:"Klipp ut","delete":"Slett",indent:"Innrykk",insertHorizontalRule:"Vannrett strek",insertOrderedList:"Nummerert liste",insertUnorderedList:"Punktliste",italic:"Kursiv",justifyCenter:"Midtstill",justifyFull:"Juster",
justifyLeft:"Venstrejuster",justifyRight:"H\u00f8yrejuster",outdent:"Fjern innrykk",paste:"Lim inn",redo:"Gj\u00f8r om",removeFormat:"Fjern format",selectAll:"Velg alle",strikethrough:"Gjennomstreking",subscript:"Senket skrift",superscript:"Hevet skrift",underline:"Understreking",undo:"Angre",unlink:"Fjern kobling",createLink:"Opprett kobling",toggleDir:"Bytt retning",insertImage:"Sett inn bilde",insertTable:"Sett inn/rediger tabell",toggleTableBorder:"Bytt tabellkant",deleteTable:"Slett tabell",
tableProp:"Tabellegenskap",htmlToggle:"HTML-kilde",foreColor:"Forgrunnsfarge",hiliteColor:"Bakgrunnsfarge",plainFormatBlock:"Avsnittsstil",formatBlock:"Avsnittsstil",fontSize:"Skriftst\u00f8rrelse",fontName:"Skriftnavn",tabIndent:"Tabulatorinnrykk",fullScreen:"Sl\u00e5 p\u00e5/av full skjerm",viewSource:"Vis HTML-kilde",print:"Skriv ut",newPage:"Ny side",systemShortcut:'Handlingen "${0}" er bare tilgjengelig i nettleseren ved hjelp av en tastatursnarvei. Bruk ${1}.',ctrlKey:"ctrl+${0}",appleKey:"\u2318${0}",
_localized:{}},"dijit/_editor/nls/FontChoice":{1:"xx-liten",2:"x-liten",3:"liten",4:"middels",5:"stor",6:"x-stor",7:"xx-stor",fontSize:"St\u00f8rrelse",fontName:"Skrift",formatBlock:"Format",serif:"serif","sans-serif":"sans-serif",monospace:"monospace",cursive:"kursiv",fantasy:"fantasi",noFormat:"Ingen",p:"Avsnitt",h1:"Overskrift",h2:"Undertittel",h3:"Under-undertittel",pre:"Forh\u00e5ndsformatert",_localized:{}},"dojox/editor/plugins/nls/latinEntities":{iexcl:"invertert utropstegn",cent:"cent-tegn",
pound:"pund-tegn",curren:"valutategn",yen:"yen-tegn\nyuan-tegn",brvbar:"brutt strek\nbrutt loddrett strek",sect:"seksjonstegn",uml:"dieresis",copy:"opphavsrettstegn",ordf:"feminin ordenstallsindikator",laquo:"venstre doble anf\u00f8rselstegn",not:"ikke-tegn",shy:"myk bindestrek",reg:"registrert-tegn\nregistrert varemerke-tegn",macr:"makron\nmellomromsmakron\noverstrek\nAPL-overstrek",deg:"gradtegn",plusmn:"pluss-minus-tegn\npluss-eller-minus-tegn",sup2:"hevet skrift to\nhevet skrift tall to\nkvadrat",
sup3:"hevet skrift tre\nhevet skrift tall tre\nkubikk",acute:"akuttegn\nmellomromsakuttegn",micro:"mikro-tegn",para:"avsnittstegn",middot:"midtprikk\nGeorgisk komma\ngresk midtprikk",cedil:"cedille\nmellomromscedille",sup1:"hevet skrift en\nhevet skrift tall en",ordm:"maskulin ordenstallsindikator",raquo:"h\u00f8yre doble anf\u00f8rselstegn",frac14:"br\u00f8k en kvart",frac12:"br\u00f8k en halv",frac34:"br\u00f8k tre kvart",iquest:"invertert sp\u00f8rsm\u00e5lstegn\nsnudd sp\u00f8rsm\u00e5lstegn",
Agrave:"Stor bokstav A med aksent grave\nStor bokstav A grave",Aacute:"Stor bokstav A med aigu",Acirc:"Stor bokstav A med circumfleks",Atilde:"Stor bokstav A med tilde",Auml:"Stor bokstav A med dieresis",Aring:"Stor bokstav A med ring\nStor bokstav A ring",AElig:"Stor bokstav AE\nStor bokstav sammenbundet AE",Ccedil:"Stor bokstav C med cedille",Egrave:"Stor bokstav E med grave",Eacute:"Stor bokstav E med aigu",Ecirc:"Stor bokstav E med circumfleks",Euml:"Stor bokstav E med diaeresis",Igrave:"Stor bokstav I med grave",
Iacute:"Stor bokstav I med aigu",Icirc:"Stor bokstav I med circumflex",Iuml:"Stor bokstav I med dieresis",ETH:"Stor bokstav ETH",Ntilde:"Stor bokstav N med tilde",Ograve:"Stor bokstav O med grave",Oacute:"Stor bokstav O med aigu",Ocirc:"Stor bokstav O med circumfleks",Otilde:"Stor bokstav O med tilde",Ouml:"Stor bokstav O med dieresis",times:"multiplikasjonstegn",Oslash:"Stor bokstav O med strek\nStor bokstav O skr\u00e5strek",Ugrave:"Stor bokstav U med grave",Uacute:"Stor bokstav U med aigu",Ucirc:"Stor bokstav U med circumflex",
Uuml:"Stor bokstav U med dieresis",Yacute:"Stor bokstav Y med aigu",THORN:"Stor bokstav THORN",szlig:"liten bokstav dobbelt-s\neszett",agrave:"Liten bokstav a med aksent grave\nLiten bokstav a grave",aacute:"Liten bokstav a med aigu",acirc:"Liten bokstav a med circumfleks",atilde:"Liten bokstav a med tilde",auml:"Liten bokstav a med dieresis",aring:"Liten bokstav a med aksent grave\nLiten bokstav a ring",aelig:"Liten bokstav ae\nLiten bokstav sammenbundet AE",ccedil:"Liten bokstav c med cedille",
egrave:"Liten bokstav e med grave",eacute:"Liten bokstav e med aigu",ecirc:"Liten bokstav e med circumflex",euml:"Liten bokstav e med dieresis",igrave:"Liten bokstav i med grave",iacute:"Liten bokstav i med aigu",icirc:"Liten bokstav i med circumflex",iuml:"Liten bokstav i med dieresis",eth:"Liten bokstav eth",ntilde:"Liten bokstav n med tilde",ograve:"Liten bokstav o med grave",oacute:"Liten bokstav o med aigu",ocirc:"Liten bokstav o med circumflex",otilde:"Liten bokstav o med tilde",ouml:"Liten bokstav o med dieresis",
divide:"divisjonstegn",oslash:"Liten bokstav o med strek\nLiten bokstav o skr\u00e5strek",ugrave:"Liten bokstav u med grave",uacute:"Liten bokstav u med aigu",ucirc:"Liten bokstav u med circumfleks",uuml:"Liten bokstav u med dieresis",yacute:"Liten bokstav y med aigu",thorn:"Liten bokstav thorn",yuml:"Liten bokstav y med dieresis",fnof:"Liten bokstav f med krok\nfunksjon\nflorin",Alpha:"Gresk stor bokstav alfa",Beta:"Gresk stor bokstav beta",Gamma:"Gresk stor bokstav gamma",Delta:"Gresk stor bokstav delta",
Epsilon:"Gresk stor bokstav epsilon",Zeta:"Gresk stor bokstav zeta",Eta:"Gresk stor bokstav eta",Theta:"Gresk stor bokstav theta",Iota:"Gresk stor bokstav iota",Kappa:"Gresk stor bokstav kappa",Lambda:"Gresk stor bokstav lambda",Mu:"Gresk stor bokstav my",Nu:"Gresk stor bokstav ny",Xi:"Gresk stor bokstav ksi",Omicron:"Gresk stor bokstav omikron",Pi:"Gresk stor bokstav pi",Rho:"Gresk stor bokstav rho",Sigma:"Gresk stor bokstav sigma",Tau:"Gresk stor bokstav tau",Upsilon:"Gresk stor bokstav ypsilon",
Phi:"Gresk stor bokstav phi",Chi:"Gresk stor bokstav khi",Psi:"Gresk stor bokstav psi",Omega:"Gresk stor bokstav omega",alpha:"Gresk liten bokstav alfa",beta:"Gresk liten bokstav beta",gamma:"Gresk liten bokstav gamma",delta:"Gresk liten bokstav delta",epsilon:"Gresk liten bokstav epsilon",zeta:"Gresk liten bokstav zeta",eta:"Gresk liten bokstav eta",theta:"Gresk liten bokstav theta",iota:"Gresk liten bokstav iota",kappa:"Gresk liten bokstav kappa",lambda:"Gresk liten bokstav lambda",mu:"Gresk liten bokstav my",
nu:"Gresk liten bokstav ny",xi:"Gresk liten bokstav ksi",omicron:"Gresk liten bokstav omikron",pi:"Gresk liten bokstav pi",rho:"Gresk liten bokstav rho",sigmaf:"Gresk liten bokstav sluttform sigma",sigma:"Gresk liten bokstav sigma",tau:"Gresk liten bokstav tau",upsilon:"Gresk liten bokstav ypsilon",phi:"Gresk liten bokstav phi",chi:"Gresk liten bokstav khi",psi:"Gresk liten bokstav psi",omega:"Gresk liten bokstav omega",thetasym:"Gresk liten bokstav theta-symbol",upsih:"Gresk ypsilon med krok-symbol",
piv:"Gresk pi-symbol",bull:"punkt\nliten svart sirkel",hellip:"vannrett ellipse\ntre prikker",prime:"prim\nminutter\nfot",Prime:"dobbelt prim\nsekunder\ntommer",oline:"overstrek\nmellomromsoverstrek",frasl:"br\u00f8kskr\u00e5strek",weierp:"script capital P\npower set\nWeierstrass p",image:"blackletter capital I\nimaginary part",real:"blackletter capital R\nreal part symbol",trade:"varemerketegn",alefsym:"alef symbol\nfirst transfinite cardinal",larr:"venstrepil",uarr:"opp-pil",rarr:"h\u00f8yrepil",
darr:"nedpil",harr:"venstre-h\u00f8yre-pil",crarr:"nedpil med hj\u00f8rne mot venstre\nretur",lArr:"dobbeltpil mot venstre",uArr:"dobbeltpil oppover",rArr:"dobbeltpil mot h\u00f8yre",dArr:"dobbeltpil nedover",hArr:"dobbeltpil venstre-h\u00f8yre",forall:"for alle",part:"partiell differensial",exist:"det finnes",empty:"tomt sett\nnullsett\ndiameter",nabla:"nabla\nbakoverdifferanse",isin:"element av",notin:"ikke et element av",ni:"contains as member",prod:"n-\u00e6rt produkt\nprodukttegn",sum:"n-\u00e6r summering",
minus:"minustegn",lowast:"stjerneoperator",radic:"kvadratrot\nradikaltegn",prop:"proporsjonalt med",infin:"uendelighet",ang:"vinkel",and:"logisk og\nkile",or:"logisk eller\nv",cap:"snitt\nbue",cup:"union\nkopp","int":"integral",there4:"derfor",sim:"tilde-operator\nvarierer med\nlikner p\u00e5",cong:"omtrent lik",asymp:"nesten lik\nasymptotisk med",ne:"ikke lik",equiv:"identisk med",le:"mindre enn eller lik",ge:"st\u00f8rre enn eller lik",sub:"delsett av",sup:"overordnet sett av",nsub:"ikke delsett av",
sube:"delsett av eller lik",supe:"overordnet sett av eller lik",oplus:"pluss med sirkel\ndirekte sum",otimes:"circled times\nvector product",perp:"up tack\northogonal to\nperpendicular",sdot:"dot operator",lceil:"left ceiling\nAPL upstile",rceil:"right ceiling",lfloor:"left floor\nAPL downstile",rfloor:"right floor",lang:"left-pointing angle bracket",rang:"right-pointing angle bracket",loz:"lozenge",spades:"black spade suit",clubs:"black club suit\nshamrock",hearts:"black heart suit\nvalentine",diams:"black diamond suit",
OElig:"Stor bokstav ligatur OE",oelig:"Liten bokstav ligatur oe",Scaron:"Latin capital letter S with caron",scaron:"Latin small letter s with caron",Yuml:"Latin capital letter Y with diaeresis",circ:"modifier letter circumflex accent",tilde:"liten tilde",ensp:"en-mellomrom",emsp:"em-mellomrom",thinsp:"tynt mellomrom",zwnj:"zero width non-joiner",zwj:"zero width joiner",lrm:"left-to-right mark",rlm:"right-to-left mark",ndash:"en-strek",mdash:"em-strek",lsquo:"venstre enkelt anf\u00f8rselstegn",rsquo:"h\u00f8yre enkelt anf\u00f8rselstegn",
sbquo:"single low-9 quotation mark",ldquo:"venstre dobbelt anf\u00f8rselstegn",rdquo:"h\u00f8yre dobbelt anf\u00f8rselstegn",bdquo:"double low-9 quotation mark",dagger:"dolk",Dagger:"dobbelt dolk",permil:"promilletegn",lsaquo:"single left-pointing angle quotation mark",rsaquo:"single right-pointing angle quotation mark",euro:"euro-tegn",_localized:{}},"dojox/editor/plugins/nls/InsertEntity":{insertEntity:"Sett inn symbol",_localized:{}},"dojo/nls/colors":{aliceblue:"bl\u00e5hvit",antiquewhite:"antikk hvit",
aqua:"akva",aquamarine:"akvamarin",azure:"asur",beige:"beige",bisque:"gulrosa",black:"svart",blanchedalmond:"lys mandel",blue:"bl\u00e5",blueviolet:"bl\u00e5fiolett",brown:"brun",burlywood:"matt mellombrun",cadetblue:"m\u00f8rk gr\u00f8nnbl\u00e5",chartreuse:"l\u00f8vgr\u00f8nn",chocolate:"sjokolade",coral:"korall",cornflowerblue:"kornbl\u00e5",cornsilk:"cornsilk",crimson:"karmosinr\u00f8dt",cyan:"cyan",darkblue:"m\u00f8rk bl\u00e5",darkcyan:"m\u00f8rk cyan",darkgoldenrod:"m\u00f8rk gyldenris",darkgray:"m\u00f8rk gr\u00e5",
darkgreen:"m\u00f8rk gr\u00f8nn",darkgrey:"m\u00f8rk gr\u00e5",darkkhaki:"m\u00f8rk khaki",darkmagenta:"m\u00f8rk magenta",darkolivegreen:"m\u00f8rk olivengr\u00f8nn",darkorange:"m\u00f8rk oransje",darkorchid:"m\u00f8rk orkide",darkred:"m\u00f8rk r\u00f8d",darksalmon:"m\u00f8rk lakserosa",darkseagreen:"m\u00f8rk sj\u00f8gr\u00f8nn",darkslateblue:"m\u00f8rk skiferbl\u00e5",darkslategray:"m\u00f8rk skifergr\u00e5",darkslategrey:"m\u00f8rk skifergr\u00e5",darkturquoise:"m\u00f8rk turkis",darkviolet:"m\u00f8rk fiolett",
deeppink:"dyp rosa",deepskyblue:"dyp himmelbl\u00e5",dimgray:"m\u00f8rk m\u00f8rkegr\u00e5",dimgrey:"m\u00f8rk m\u00f8rkegr\u00e5",dodgerblue:"lys havbl\u00e5",firebrick:"mursteinsr\u00f8d",floralwhite:"blomsterhvit",forestgreen:"skoggr\u00f8nn",fuchsia:"fuksia",gainsboro:"lys lys gr\u00e5",ghostwhite:"egghvit",gold:"gull",goldenrod:"gyldenris",gray:"gr\u00e5",green:"gr\u00f8nn",greenyellow:"gulgr\u00f8nn",grey:"gr\u00e5",honeydew:"gr\u00f8nnhvit",hotpink:"halvm\u00f8rk rosa",indianred:"rustr\u00f8d",
indigo:"indigo",ivory:"elfenbenshvit",khaki:"khaki",lavender:"lavendel",lavenderblush:"lillahvit",lawngreen:"plengr\u00f8nn",lemonchiffon:"ferskenfarget",lightblue:"lys bl\u00e5",lightcoral:"lys korall",lightcyan:"lys cyan",lightgoldenrodyellow:"lys gyldenrisgul",lightgray:"lys gr\u00e5",lightgreen:"lys gr\u00f8nn",lightgrey:"lys gr\u00e5",lightpink:"lys rosa",lightsalmon:"lys lakserosa",lightseagreen:"lys sj\u00f8gr\u00f8nn",lightskyblue:"lys himmelbl\u00e5",lightslategray:"lys skifergr\u00e5",lightslategrey:"lys skifergr\u00e5",
lightsteelblue:"lys st\u00e5lbl\u00e5",lightyellow:"lys gul",lime:"lime",limegreen:"limegr\u00f8nn",linen:"lin",magenta:"magenta",maroon:"r\u00f8dbrun",mediumaquamarine:"middels akvamarin",mediumblue:"mellombl\u00e5",mediumorchid:"middels orkide",mediumpurple:"middels purpur",mediumseagreen:"middels sj\u00f8gr\u00f8nn",mediumslateblue:"middels skiferbl\u00e5",mediumspringgreen:"middels v\u00e5rgr\u00f8nn",mediumturquoise:"middels turkis",mediumvioletred:"middels fiolettr\u00f8d",midnightblue:"midnattsbl\u00e5",
mintcream:"mintkrem",mistyrose:"lys rosenr\u00f8d",moccasin:"lys gulbrun",navajowhite:"gulbrun",navy:"marinebl\u00e5",oldlace:"kniplingshvit",olive:"oliven",olivedrab:"middels olivengr\u00f8nn",orange:"oransje",orangered:"r\u00f8doransje",orchid:"orkide",palegoldenrod:"svak gyldenris",palegreen:"svak gr\u00f8nn",paleturquoise:"svak turkis",palevioletred:"svak fiolettr\u00f8d",papayawhip:"lys papaya",peachpuff:"brunrosa",peru:"lys n\u00f8ttebrun",pink:"rosa",plum:"plommefarget",powderblue:"lys gr\u00f8nnbl\u00e5",
purple:"purpur",red:"r\u00f8d",rosybrown:"brunlilla",royalblue:"kongebl\u00e5",saddlebrown:"m\u00f8rk n\u00f8ttebrun",salmon:"lakserosa",sandybrown:"sandbrun",seagreen:"sj\u00f8gr\u00f8nn",seashell:"skjellhvit",sienna:"n\u00f8ttebrun",silver:"s\u00f8lvfarget",skyblue:"himmelbl\u00e5",slateblue:"skiferbl\u00e5",slategray:"skifergr\u00e5",slategrey:"skifergr\u00e5",snow:"sn\u00f8hvit",springgreen:"v\u00e5rgr\u00f8nn",steelblue:"st\u00e5lbl\u00e5",tan:"matt mellombrun",teal:"m\u00f8rk gr\u00f8nnbl\u00e5",
thistle:"lys gr\u00e5lilla",tomato:"tomatr\u00f8d",transparent:"gjennomsiktig",turquoise:"turkis",violet:"fiolett",wheat:"varm sienna",white:"hvit",whitesmoke:"r\u00f8ykhvit",yellow:"gul",yellowgreen:"gulgr\u00f8nn",_localized:{}},"dojox/widget/nls/ColorPicker":{redLabel:"r",greenLabel:"g",blueLabel:"b",hueLabel:"h",saturationLabel:"s",valueLabel:"v",degLabel:"\u00b0",hexLabel:"hex",huePickerTitle:"Nyansevelger",saturationPickerTitle:"Metningsvelger",_localized:{}},"dojox/editor/plugins/nls/TableDialog":{insertTableTitle:"Sett inn tabell",
modifyTableTitle:"Endre tabell",rows:"Rader:",columns:"Kolonner:",align:"Juster:",cellPadding:"Celleutfylling:",cellSpacing:"Celleavstand:",tableWidth:"Tabellbredde:",backgroundColor:"Bakgrunnsfarge:",borderColor:"Kantlinjefarge:",borderThickness:"Kantlinjetykkelse:",percent:"prosent",pixels:"piksler","default":"standard",left:"venstre",center:"midtstill",right:"h\u00f8yre",buttonSet:"Definer",buttonInsert:"Sett inn",buttonCancel:"Avbryt",selectTableLabel:"Velg tabell",insertTableRowBeforeLabel:"Legg til rad foran",
insertTableRowAfterLabel:"Legg til rad etter",insertTableColumnBeforeLabel:"Legg til kolonne foran",insertTableColumnAfterLabel:"Legg til kolonne etter",deleteTableRowLabel:"Slett rad",deleteTableColumnLabel:"Slett kolonne",colorTableCellTitle:"Tabellcelle for bakgrunnsfarge",tableContextMenuTitle:"Tabellhurtigmeny",_localized:{}},"dojox/editor/plugins/nls/PasteFromWord":{pasteFromWord:"Lim inn fra Word",instructions:"Lim inn innhold fra Word til tekstboksen nedenfor. N\u00e5r du er forn\u00f8yd med innholdet du skal sette inn, trykker du p\u00e5 innlimingsknappen. Hvis du vil avbryte innsettingen av teksten, trykker du p\u00e5 avbruddsknappen.",
_localized:{}},"dojox/editor/plugins/nls/InsertAnchor":{insertAnchor:"Sett inn anker",title:"Ankeregenskaper",anchor:"Navn:",text:"Beskrivelse:",set:"Definer",cancel:"Avbryt",_localized:{}},"dojox/editor/plugins/nls/Blockquote":{blockquote:"Blokksitat",_localized:{}},"dojox/editor/plugins/nls/LocalImage":{insertImageTitle:"Sett inn bilde",url:"Bilde",browse:"Bla gjennom...",text:"Beskrivelse",set:"Sett inn",invalidMessage:"Ugyldig bildefiltype",prePopuTextUrl:"Angi en bilde-URL",prePopuTextBrowse:" eller bla gjennom til en lokal fil.",
_localized:{}}});
//# sourceMappingURL=pmbdojo_nb.js.map